# Jupyter Community Call

## September 24th, 2019

**Date:** September 24, 2019, at 9am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2019-09-24/09:00/Jupyter%20Community%20Call))

**Link:** [Youtube Video](https://youtu.be/so9F-Ha4q4U)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make *short* announcements (without a need for discussion). 

* [Co-locating a Jupyter Server and Dask Scheduler _By Matthew Rocklin](https://blog.dask.org/2019/09/13/jupyter-on-dask) [name=tonyfast]

* [Language server protocol](https://github.com/jupyterlab/jupyterlab/issues/2163)
  * [current work on jupyterlab-lsp](https://github.com/krassowski/jupyterlab-lsp) [name=krassowski]
  * [wip binder](https://mybinder.org/v2/gh/bollwyvl/jupyterlab-lsp/add-traitlets-proxy?urlpath=lab%2Ftree%2Fexamples%2FPython.ipynb) [name=bollwyvl]

## Agenda Items

Add agenda items here **before** the meeting. We will reorganize the agenda so that it fits in the 60m meeting slot.

* **[importing notebooks with `importnb`](https://gist.github.com/tonyfast/15c6ac8f005a5522291f08d95619e085)** [name=tonyfast]

  > _[`importnb`](https://github.com/deathbeds/importnb) provides easy, flexible reuse of IPython notebooks from other notebooks, `.py` scripts and libraries, and even the command line._

* **[🤖 RobotLab: a one-click Jupyter and Robot Framework environment](https://github.com/robots-from-jupyter/robotlab)** [name=bollwyvl]

  > _`RobotLab` was built to support a workshop introducing [acceptance-test-driven](https://en.wikipedia.org/wiki/Acceptance_testing) development and robot process automation with [robotkernel](https://github.com/robots-from-jupyter/robotkernel), a [Robot Framework](https://robotframework.org/) kernel, in JupyterLab. It is built with [conda](https://github.com/conda/conda), [constructor](https://github.com/conda/constructor) and [azure pipelines](https://azure.microsoft.com/en-us/services/devops/pipelines). You can use the [installers](https://github.com/robots-from-jupyter/robotlab/releases/tag/v2019.9.0) to learn how you can use Robot Framework and Jupyter, or adapt its pipeline to produce your own, cross-platform installers_
  > 

* **Project Drawdown** [name=dgentry]
  > _Project Drawdown is a global research organization that identifies, reviews, and analyzes the most viable solutions to climate change, and shares these findings with the world._
  > _We'll show current state of climate solution models using Voila and JupyterHub, and ask for suggestions about git operation driven from the Notebook._



## Attendees


- Zach     | Jupyter Cal Poly          | @Zsailer        |
- Denton   | Project Drawdown          | @DentonGentry   |
- Nick     | GTRI                      | @nrbgt          |
- Chico Venancio | BMC Group K. K.     | @chicocvenancio |
- Tony Fast | Quansight | @tonyfast |
- Wayne Decatur | Upstate Medical | @fomightez |
- Kevin Bates | IBM | @kevin-bates |
- Carol | Jupyter | @willingc |
